==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property statements The statements to combine.
 */
public data class WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs(
    public val statements: Output<List<WebAclRuleStatementArgs>>,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs.builder()
            .statements(
                statements.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs].
 */
@PulumiTagMarker
public class WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgsBuilder internal
constructor() {
    private var statements: Output<List<WebAclRuleStatementArgs>>? = null

    /**
     * @param value The statements to combine.
     */
    @JvmName("onhobvtlcdwxbchj")
    public suspend fun statements(`value`: Output<List<WebAclRuleStatementArgs>>) {
        this.statements = value
    }

    @JvmName("dfwuncvlknsegvqh")
    public suspend fun statements(vararg values: Output<WebAclRuleStatementArgs>) {
        this.statements = Output.all(values.asList())
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("aiaoxxrqalgpwkjx")
    public suspend fun statements(values: List<Output<WebAclRuleStatementArgs>>) {
        this.statements = Output.all(values)
    }

    /**
     * @param value The statements to combine.
     */
    @JvmName("xeoiwwbltkjyhtak")
    public suspend fun statements(`value`: List<WebAclRuleStatementArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("ejlgbxmchcuixxtp")
    public suspend fun statements(argument: List<suspend WebAclRuleStatementArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WebAclRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("khhurqadeelaofli")
    public suspend fun statements(
        vararg
        argument: suspend WebAclRuleStatementArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            WebAclRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("vripastimiclqmen")
    public suspend fun statements(argument: suspend WebAclRuleStatementArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WebAclRuleStatementArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("dfjcroyokduoafcc")
    public suspend fun statements(vararg values: WebAclRuleStatementArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    internal fun build(): WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs =
        WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs(
            statements = statements ?: throw PulumiNullFieldException("statements"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property statements The statements to combine.
 */
public data class WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs(
    public val statements: Output<List<WebAclRuleStatementArgs>>,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs.builder()
            .statements(
                statements.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs].
 */
@PulumiTagMarker
public class WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgsBuilder internal constructor() {
    private var statements: Output<List<WebAclRuleStatementArgs>>? = null

    /**
     * @param value The statements to combine.
     */
    @JvmName("hrrbxmfmvgkkgkpl")
    public suspend fun statements(`value`: Output<List<WebAclRuleStatementArgs>>) {
        this.statements = value
    }

    @JvmName("jcdywwitgoqqlpdr")
    public suspend fun statements(vararg values: Output<WebAclRuleStatementArgs>) {
        this.statements = Output.all(values.asList())
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("rownrkbdtruundik")
    public suspend fun statements(values: List<Output<WebAclRuleStatementArgs>>) {
        this.statements = Output.all(values)
    }

    /**
     * @param value The statements to combine.
     */
    @JvmName("mtoahyqhqtydlfiu")
    public suspend fun statements(`value`: List<WebAclRuleStatementArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("onvaulxdbyoufhak")
    public suspend fun statements(argument: List<suspend WebAclRuleStatementArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WebAclRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("gvipwyacmkwpiudl")
    public suspend fun statements(vararg argument: suspend WebAclRuleStatementArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            WebAclRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("ckgwieampfufhknh")
    public suspend fun statements(argument: suspend WebAclRuleStatementArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WebAclRuleStatementArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("mragcpatstxognnx")
    public suspend fun statements(vararg values: WebAclRuleStatementArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    internal fun build(): WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs =
        WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementArgs(
            statements = statements ?: throw PulumiNullFieldException("statements"),
        )
}
